<a id="packages.open_aea.protocols.signing.tests.test_signing_messages"></a>

# packages.open`_`aea.protocols.signing.tests.test`_`signing`_`messages

Test messages module for signing protocol.

<a id="packages.open_aea.protocols.signing.tests.test_signing_messages.TestMessageSigning"></a>

## TestMessageSigning Objects

```python
class TestMessageSigning(BaseProtocolMessagesTestCase)
```

Test for the 'signing' protocol message.

<a id="packages.open_aea.protocols.signing.tests.test_signing_messages.TestMessageSigning.build_messages"></a>

#### build`_`messages

```python
def build_messages() -> List[SigningMessage]
```

Build the messages to be used for testing.

<a id="packages.open_aea.protocols.signing.tests.test_signing_messages.TestMessageSigning.build_inconsistent"></a>

#### build`_`inconsistent

```python
def build_inconsistent() -> List[SigningMessage]
```

Build inconsistent messages to be used for testing.

